import { Injectable, ɵɵdefineInjectable, Component, ElementRef, ChangeDetectorRef, Input, NgModule } from '@angular/core';
import { __awaiter } from 'tslib';
import { HttpClient } from '@angular/common/http';
import { trigger, transition, style, animate } from '@angular/animations';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/code-show.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CodeShowService {
    constructor() { }
}
CodeShowService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
CodeShowService.ctorParameters = () => [];
/** @nocollapse */ CodeShowService.ngInjectableDef = ɵɵdefineInjectable({ factory: function CodeShowService_Factory() { return new CodeShowService(); }, token: CodeShowService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * Generated from: lib/code-show.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
const Language = {
    Html: "html",
    Typescript: "typescript",
};
class CodeShowComponent {
    /**
     * @param {?} _http
     * @param {?} _elementRef
     * @param {?} _changeDetectorRef
     */
    constructor(_http, _elementRef, _changeDetectorRef) {
        this._http = _http;
        this._elementRef = _elementRef;
        this._changeDetectorRef = _changeDetectorRef;
        this.componentName = '';
        this.htmlCode = '';
        this.typescriptCode = '';
        this.expanded = false;
        this.fetchingCode = false;
        this.selectedLanguage = Language.Html;
        this.Language = Language;
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @return {?}
     */
    toggle() {
        this.expanded = !this.expanded;
        if (this.expanded) {
            /** @type {?} */
            const codeForSelectedLanguage = this.selectedLanguage === Language.Html ? this.htmlCode : this.typescriptCode;
            if (!codeForSelectedLanguage) {
                this.fetchCode();
            }
            else {
                this._changeDetectorRef.detectChanges();
                this.highlightCode();
            }
        }
    }
    /**
     * @param {?} language
     * @return {?}
     */
    switchLanguage(language) {
        if (language === this.selectedLanguage) {
            return;
        }
        this.selectedLanguage = language;
        /** @type {?} */
        const codeForSelectedLanguage = this.selectedLanguage === Language.Html ? this.htmlCode : this.typescriptCode;
        if (!codeForSelectedLanguage) {
            this.fetchCode();
        }
        else {
            this._changeDetectorRef.detectChanges();
            this.highlightCode();
        }
    }
    /**
     * @return {?}
     */
    highlightCode() {
        /** @type {?} */
        const codeElem = this._elementRef.nativeElement.querySelector(`code.language-${this.selectedLanguage}`);
        hljs.highlightBlock(codeElem);
    }
    /**
     * @return {?}
     */
    fetchCode() {
        return __awaiter(this, void 0, void 0, function* () {
            this.fetchingCode = true;
            try {
                /** @type {?} */
                const fileUrl = `https://raw.githubusercontent.com/seidme/flxng/development/src/app/showcase-treetable/${this.composeComponentPath()}`;
                /** @type {?} */
                const code = yield this._http.get(fileUrl, { responseType: 'text' }).toPromise();
                this.fetchingCode = false;
                this.selectedLanguage === Language.Html ? (this.htmlCode = code) : (this.typescriptCode = code);
                this._changeDetectorRef.detectChanges();
                this.highlightCode();
            }
            catch (e) {
                this.fetchingCode = false;
                console.log('error: ', e);
            }
        });
    }
    /**
     * @return {?}
     */
    composeComponentPath() {
        /** @type {?} */
        const fileExtension = this.selectedLanguage === Language.Html ? 'html' : 'ts';
        /** @type {?} */
        const componentNameFragments = this.componentName.split('-');
        /** @type {?} */
        const componentExampleSuffix = componentNameFragments[componentNameFragments.length - 1];
        /** @type {?} */
        const mainComponentName = this.componentName.replace('-' + componentExampleSuffix, '');
        return `${mainComponentName}/${this.componentName}/${this.componentName}.component.${fileExtension}`;
    }
    /**
     * @return {?}
     */
    copyCode() {
        // const codeElem = this._elementRef.nativeElement.querySelector(`code.language-${this.selectedLanguage}`);
        // codeElem.focus();
        // codeElem.select();
        // document.execCommand('copy');
        // const codeElem = this._elementRef.nativeElement.querySelector(`code.language-${this.selectedLanguage}`);
        // codeElem.focus();
        // codeElem.select();
        // document.execCommand('copy');
        // Page needs to be served over HTTPS in order the following to work!
        /** @type {?} */
        const codeForSelectedLanguage = this.selectedLanguage === Language.Html ? this.htmlCode : this.typescriptCode;
        navigator.clipboard.writeText(codeForSelectedLanguage).then((/**
         * @return {?}
         */
        () => { }), (/**
         * @param {?} e
         * @return {?}
         */
        e => {
            console.log(e);
            console.error('Works only if page is served over HTTPS!');
        }));
    }
}
CodeShowComponent.decorators = [
    { type: Component, args: [{
                selector: 'flx-code-show',
                template: "<div class=\"container\"\r\n     [class.expanded]=\"expanded\">\r\n  <div class=\"opener\">\r\n    <button type=\"button\"\r\n            (click)=\"toggle()\">{{expanded ? 'Collapse' : 'View code'}}</button>\r\n  </div>\r\n\r\n  <div class=\"content\"\r\n       [@expansion]=\"'expansion'\"\r\n       *ngIf=\"expanded && (htmlCode || typescriptCode)\">\r\n    <div class=\"controls\">\r\n      <div class=\"languages\">\r\n        <button type=\"button\"\r\n                [class.selected]=\"selectedLanguage === Language.Html\"\r\n                (click)=\"switchLanguage(Language.Html)\">HTML</button>\r\n        &nbsp;\r\n        <button type=\"button\"\r\n                [class.selected]=\"selectedLanguage === Language.Typescript\"\r\n                (click)=\"switchLanguage(Language.Typescript)\"> TS </button>\r\n      </div>\r\n\r\n      <div>\r\n        <button type=\"button\"\r\n                (click)=\"copyCode()\"> Copy </button>\r\n      </div>\r\n    </div>\r\n\r\n    <pre\r\n         *ngIf=\"selectedLanguage === Language.Html && !fetchingCode\"><code class=\"language-{{selectedLanguage}}\">{{htmlCode}}</code></pre>\r\n    <pre\r\n         *ngIf=\"selectedLanguage === Language.Typescript && !fetchingCode\"><code class=\"language-{{selectedLanguage}}\">{{typescriptCode}}</code></pre>\r\n  </div>\r\n</div>",
                animations: [
                    trigger('expansion', [
                        transition('void => expansion', [style({ height: 0 }), animate('120ms ease-out', style({ height: '*' }))]),
                        transition('expansion => void', [style({ height: '*' }), animate('120ms ease-out', style({ height: '0' }))])
                    ])
                ],
                styles: [":host .container .opener{margin:1rem}:host .container .content{background:#e9ecf5;padding:.2rem;border-radius:.2rem}:host .container .content pre{margin:0}:host .container .content .controls{display:-webkit-box;display:flex;-webkit-box-pack:justify;justify-content:space-between;-webkit-box-align:center;align-items:center;margin:.2rem}:host .container .content .controls .languages{display:-webkit-box;display:flex;-webkit-box-pack:start;justify-content:flex-start;-webkit-box-align:center;align-items:center}:host .container .content .controls button{height:2rem;background:#fff}:host .container .content .controls button:hover{background:#e3e7f3}:host .container .content .controls button:active{background:#dae1f6}:host .container .content .controls button.selected{background:#e9ecf5}:host button{height:2.5rem;min-width:4rem;cursor:pointer;border:0;background:#e9ecf5;border-radius:.2rem;box-shadow:0 3px 4px 0 rgba(0,0,0,.14),0 2px 2px -2px rgba(0,0,0,.2),0 1px 2px 0 rgba(0,0,0,.12);color:#40337f;font-weight:700}:host button:hover{background:#e3e7f3}:host button:focus{outline:0}:host button.selected{background:#e3e8f8}:host button:active{background:#dae1f6}"]
            }] }
];
/** @nocollapse */
CodeShowComponent.ctorParameters = () => [
    { type: HttpClient },
    { type: ElementRef },
    { type: ChangeDetectorRef }
];
CodeShowComponent.propDecorators = {
    componentName: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    CodeShowComponent.prototype.componentName;
    /** @type {?} */
    CodeShowComponent.prototype.htmlCode;
    /** @type {?} */
    CodeShowComponent.prototype.typescriptCode;
    /** @type {?} */
    CodeShowComponent.prototype.expanded;
    /** @type {?} */
    CodeShowComponent.prototype.fetchingCode;
    /** @type {?} */
    CodeShowComponent.prototype.selectedLanguage;
    /** @type {?} */
    CodeShowComponent.prototype.Language;
    /**
     * @type {?}
     * @private
     */
    CodeShowComponent.prototype._http;
    /**
     * @type {?}
     * @private
     */
    CodeShowComponent.prototype._elementRef;
    /**
     * @type {?}
     * @private
     */
    CodeShowComponent.prototype._changeDetectorRef;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/code-show.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CodeShowModule {
}
CodeShowModule.decorators = [
    { type: NgModule, args: [{
                declarations: [CodeShowComponent],
                imports: [CommonModule],
                exports: [CodeShowComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: flxng-code-show.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { CodeShowComponent, CodeShowModule, CodeShowService, Language };
//# sourceMappingURL=flxng-code-show.js.map
